| Title: | View Colors Used in R Objects in the Console |
|---|---|
| Description: | Output colors used in literal vectors, palettes and plot objects (ggplot). |
| Authors: | Shangchen Song [aut, cre] |
| Maintainer: | Shangchen Song <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 0.2.0 |
| Built: | 2026-05-22 08:30:36 UTC |
| Source: | https://github.com/lovestat/seecolor |
Simply highlight the text in the Source panel and the colors used in the specific object will be output in the console
pick_color(type = "mosaic", blank.len = 3)pick_color(type = "mosaic", blank.len = 3)
type |
A character. The style of printing. The default is |
blank.len |
A integer. The length of color mosaic. The default value is 3. |
pick_color(type = "mosaic", blank.len = 3) pick_color(type = "ribbon", blank.len = 3)pick_color(type = "mosaic", blank.len = 3) pick_color(type = "ribbon", blank.len = 3)
Print out the colors used by a literal vector, a palette, or a ggplot object
print_color(x, type = "mosaic", blank.len = 3)print_color(x, type = "mosaic", blank.len = 3)
x |
A literal vector, a palette, or a ggplot object |
type |
A character. The style of printing. The default is |
blank.len |
A integer. The length of color mosaic. The default value is 3. |
print_color(colors(), type = "mosaic", blank.len = 3) print_color(palette(), type = "ribbon")print_color(colors(), type = "mosaic", blank.len = 3) print_color(palette(), type = "ribbon")
Run pick_color(type = 'mosaic') as addin, you may not run
this directly by code, since it comes without arguments
z_pick_color_addin_mosaic()z_pick_color_addin_mosaic()
Run pick_color(type = 'ribbon') as addin, you may not run
this directly by code, since it comes without arguments
z_pick_color_addin_ribbon()z_pick_color_addin_ribbon()